@@ -4,7 +4,7 @@ package SOAP::WSDL::SOAP::Typelib::Fault11;
     use warnings;
     use Class::Std::Fast::Storable constructor => 'none';
 
-    use version; our $VERSION = qv('2.00.99_3');
+    use version; our $VERSION = qv('3.00.0_1');
 
     use Scalar::Util qw(blessed);
 
@@ -162,10 +162,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 861 $
+ $Rev: 851 $
  $LastChangedBy: kutterma $
- $Id: Fault11.pm 861 2010-03-28 10:41:26Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/SOAP/Typelib/Fault11.pm $
+ $Id: Fault11.pm 851 2009-05-15 22:45:18Z kutterma $
+ $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/SOAP/Typelib/Fault11.pm $
 
 =cut
 
