@@ -4,7 +4,7 @@ use warnings;
 use Class::Std::Fast::Storable;
 use base qw(SOAP::WSDL::Base);
 
-use version; our $VERSION = qv('2.00.99_3');
+use version; our $VERSION = qv('3.00.0_1');
 
 my %length_of           :ATTR(:name<length>         :default<[]>);
 my %minLength_of        :ATTR(:name<minLength>      :default<[]>);
@@ -19,7 +19,6 @@ my %minInclusive        :ATTR(:name<minInclusive>   :default<[]>);
 my %maxExclusive        :ATTR(:name<maxExclusive>   :default<[]>);
 my %maxInclusive        :ATTR(:name<maxInclusive>   :default<[]>);
 
-my %nillable_of         :ATTR(:name<nillable>       :default<()>);
 my %fixed               :ATTR(:name<fixed>          :default<[]>);
 
 my %annotation_of       :ATTR(:name<annotation>     :default<()>);
@@ -101,10 +100,18 @@ sub _serialize_single {
     $xml .= '<' . join ' ', $name, @{ $opt->{ attributes } };
     if ( $opt->{ autotype }) {
         # reverse namespace by prefix hash
-        my %prefix_of = reverse %{ $opt->{ namespace } };
         my $ns = $self->get_targetNamespace();
-        my $prefix = $prefix_of{ $ns }
-           || die 'No prefix found for namespace '. $ns;
+
+        # build a list of hash keys (eg '#default', 'tns') whose values match our namespace (eg 'urn:myNamespace')
+        (my @possible_namespace_names) = grep { $opt->{ namespace }->{$_} eq $ns } keys %{ $opt->{ namespace } };
+
+        # put any '#default' option last
+        @possible_namespace_names = sort { $a eq '#default' ? 1 : $b eq '#default' ? -1 : $a cmp $b } @possible_namespace_names;
+
+        if( grep( $_ ne '#default', @possible_namespace_names ) > 1 or ! @possible_namespace_names ) {
+            die "No prefix found for namespace $ns, or too many possible names: ``@possible_namespace_names''; there should be just one and maybe a '#default' entry";                                
+        }
+        my $prefix = $possible_namespace_names[0];
         $xml .= ' type="' . $prefix . ':' . $self->get_name() .'"';
     }
 
