@@ -10,7 +10,7 @@ require Class::Std::Fast::Storable;
 
 use base qw(SOAP::WSDL::XSD::Typelib::Builtin::anyType);
 
-use version; our $VERSION = qv('2.00.99_3');
+use version; our $VERSION = qv('3.00.0_1');
 
 # remove in 2.1
 our $AS_HASH_REF_WITHOUT_ATTRIBUTES = 0;
@@ -28,10 +28,7 @@ my %xml_attr_of     :ATTR();
 # Namespace handling
 my %xmlns_of        :ATTR();
 
-our $MAY_HAVE_CHILDREN = 1;
-
 # don't you ever dare to use this !
-our $___classes_of_ref = \%CLASSES_OF;
 our $___attributes_of_ref = \%ATTRIBUTES_OF;
 our $___xml_attribute_of_ref = \%xml_attr_of;
 
@@ -158,8 +155,7 @@ sub _factory {
         my $type = $CLASSES_OF{ $class }->{ $name }
             or croak "No class given for $name";
 
-        # require all types here
-        $type->isa('UNIVERSAL')
+        $type->can('serialize')
             or eval "require $type"
                 or croak $@;
 
@@ -334,19 +330,11 @@ sub _factory {
             # do we have some content
             if (defined $element) {
                 $element = [ $element ] if not ref $element eq 'ARRAY';
-                # from 2.00.09 on $NAMES_OF is filled - use || $_; for
+                # from 3.00.0_1 on $NAMES_OF is filled - use || $_; for
                 # backward compatibility
                 my $name = $NAMES_OF{$class}->{$_} || $_;
-
-                # get element's class for comparing with elements
-                my $element_class = $CLASSES_OF{$class}->{$_};
-
                 my $target_namespace = $_[0]->get_xmlns();
                 map {
-                    my %type_info = ($element_class ne ref $_)
-                        ? (derived => 1)
-                        : ();
-
                     # serialize element elements with their own serializer
                     # but name them like they're named here.
                     # TODO: check. element ref="" has a name???
@@ -354,17 +342,14 @@ sub _factory {
                             # serialize elements of different namespaces
                             # with namespace declaration
                             ($target_namespace ne $_->get_xmlns())
-                                ? $_->serialize({ name => $name, qualified => 1, %type_info })
-                                : $_->serialize({ name => $name
-                                    , %type_info
-                                });
+                                ? $_->serialize({ name => $name, qualified => 1 })
+                                : $_->serialize({ name => $name });
                     }
                     # serialize complextype elments (of other types) with their
                     # serializer, but add element tags around.
                     else {
-                        # TODO: check whether we have to handle
-                        # types from different namespaces special, too
-                        if (!defined $ELEMENT_FORM_QUALIFIED_OF{ $class }
+                        # default for undef is true
+                        if (! defined $ELEMENT_FORM_QUALIFIED_OF{ $class }
                             or $ELEMENT_FORM_QUALIFIED_OF{ $class }
                         ) {
                             # handle types from different namespaces
@@ -380,13 +365,13 @@ sub _factory {
                                 # warn "New namespace: ", $option_ref->{ xmlns_stack }->[-1]; 
                                 join q{}, $_->start_tag({ name => $name , 
                                     xmlns => $option_ref->{ xmlns_stack }->[-1], 
-                                    %{ $option_ref }, %type_info })
-                                    , $_->serialize({ %{ $option_ref }, %type_info })
+                                    %{ $option_ref } })
+                                    , $_->serialize($option_ref)
                                     , $_->end_tag({ name => $name , %{ $option_ref } });
                             }
                             else {
-                                join q{}, $_->start_tag({ name => $name , %{ $option_ref }, %type_info })
-                                    , $_->serialize({ %{ $option_ref }, %type_info })
+                                join q{}, $_->start_tag({ name => $name , %{ $option_ref } })
+                                    , $_->serialize($option_ref)
                                     , $_->end_tag({ name => $name , %{ $option_ref } });
                             }
                         }
@@ -407,7 +392,6 @@ sub _factory {
                             join q{}, $_->start_tag({
                                     name => $name,
                                     %{ $option_ref },
-                                    %type_info,
                                     (! defined $set_xmlns)
                                         ? (xmlns => "")
                                         : ()
@@ -686,10 +670,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 861 $
+ $Rev: 851 $
  $LastChangedBy: kutterma $
- $Id: ComplexType.pm 861 2010-03-28 10:41:26Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/XSD/Typelib/ComplexType.pm $
+ $Id: ComplexType.pm 851 2009-05-15 22:45:18Z kutterma $
+ $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/ComplexType.pm $
 
 =cut
 
